#
# spec file for package python-ptpython
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ptpython
Version:        3.0.25
Release:        1.1
Summary:        Python REPL build on top of prompt_toolkit
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/jonathanslenders/ptpython
Source:         https://files.pythonhosted.org/packages/source/p/ptpython/ptpython-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments
Requires:       python-appdirs
Requires:       python-docopt
Requires:       python-jedi >= 0.9.0
Requires:       python-prompt_toolkit >= 3.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module docopt}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module jedi >= 0.9.0}
BuildRequires:  %{python_module prompt_toolkit >= 3.0.0}
# /SECTION
Recommends:     python-ptpython-ptipython
%python_subpackages

%description
Ptpython is an advanced Python REPL.

%package ptipython
Summary:        Python REPL build on top of prompt_toolkit - IPython support
Group:          Development/Languages/Python
Requires:       python-ipython
Requires:       python-ptpython

%description ptipython
Ptpython is an advanced Python REPL.

This package provides IPython support to Ptpython.

%prep
%setup -q -n ptpython-%{version}
sed -i -e '/^#!\//, 1d' ptpython/entry_points/run_*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
rm %{buildroot}%{_bindir}/pt{,i}python?*
%python_clone -a %{buildroot}%{_bindir}/ptpython
%python_clone -a %{buildroot}%{_bindir}/ptipython

%post
%python_install_alternative ptpython

%post ptipython
%python_install_alternative ptipython

%postun
%python_uninstall_alternative ptpython

%postun ptipython
%python_uninstall_alternative ptipython

%check
# no upstream tests under tests/

%files %{python_files}
%doc CHANGELOG README.rst
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/ptpython

%files %{python_files ptipython}
%license LICENSE
%python_alternative %{_bindir}/ptipython

%changelog
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.25:
  * Fix handling of 'config file does not exist' when embedding
    ptpython.
  * Don't show "Impossible to read config file" warnings when no
    config file was passed to `run_config()`.
  * Output printing fixes:
  * Paginate exceptions if pagination is enabled.
  * Handle big outputs without running out of memory.
  * Asyncio REPL improvements:
  * From now on, passing `--asyncio` is required to activate the
    asyncio-REPL.
  * This will ensure that an event loop is created at the
    start in which we can run top-level await statements.
  * Use `get_running_loop()` instead of `get_event_loop()`.
  * Better handling of `SystemExit` and control-c in the async
    REPL.
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.23:
  * Don't print exception messages twice for unhandled
    exceptions.
  * Added cursor shape support.
  * Drop Python 3.6 support.
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.0.22
  * New features:
  - Improve rendering performance when there are many completions.
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.0.21:
  New features:
  - Make ptipython respect more config changes.
  (See: https://github.com/prompt-toolkit/ptpython/pull/110 )
  - Improved performance of `DictionaryCompleter` for slow mappings.
  Fixes:
  - Call `super()` in `PythonInputFilter`. This will prevent potentially breakage
  with an upcoming prompt_toolkit change.
  (See: https://github.com/prompt-toolkit/python-prompt-toolkit/pull/1690 )
  - Improved type annotations.
  - Added `py.typed` to the `package_data`.
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.0.20: 2021-09-14
  New features:
  - For `DictionaryCompleter`: show parentheses after methods.
  Fixes:
  - Don't crash when trying to complete broken mappings in `DictionaryCompleter`.
  - Don't crash when an older version of `black` is installed that is not
  compatible.
- Update to version 3.0.19: 2021-07-08
  Fixes:
  - Fix handling of `SystemExit` (fixes "ValueError: I/O operation on closed
  file").
  - Allow usage of `await` in assignment expressions or for-loops.
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 3.0.1
  - Fix backwards-compatibility of the `run_config` function. (used by
    django-extensions).
  - Fix input mode in status bar for block selection.
  - Upgrade to prompt_toolkit 3.0.
  - Requires at least Python 3.6.
  - Uses XDG base directory specification.
  - Added dictionary completer (off by default).
  - Added fuzzy completion (off by default).
  - Highlight keywords in completion dropdown menu.
  - Enable universal wheels.
  - Fixed embedding repl as asyncio coroutine.
  - Fixed patching stdout in embedded repl.
  - Fixed ResourceWarning in setup.py.
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix jupyter dependencies.
- Update to 2.0.4
  * Fixed ptipython.
  * Fixed config: setting of color depth.
  * Fixed auto-suggest key bindings.
  * Fixed Control-D key binding for exiting REPL when (confirm_exit=False).
  * Correctly focus/unfocus sidebar.
  * Fixed open_in_editor and suspend key bindings.
* Mon Feb  4 2019 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from descriptions.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Oct 26 2018 Todd R <toddrme2178@gmail.com>
- Update to version 2.0.3
  * Allow changing the min/max brightness.
  * Some changes for compatibility with the latest prompt_toolkit.
- Update to version 2.0.2
  * Don't crash the history browser when there was no history.
  * Set last exception in the sys module, when an exception was
    raised.
  * Require prompt_toolkit 2.0.5.
- Update to version 2.0.1
  * Upgrade to prompt_toolkit 2.0.x.
- Split IPython support into its own subpackage and make it
  python3-only. Due to the python2 version of IPython using
  prompt_toolkit 1.x and both the python3 version of IPython
  and Ptpython using prompt_toolkit 2.x, the python2 version of
  Ptpython cannot be used with IPython anymore.
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.41
  * See changelog at https://github.com/jonathanslenders/ptpython/blob/da2c5281f60c2d8a92749709219771ffaa84220f/CHANGELOG
* Thu Mar  5 2015 toddrme2178@gmail.com
- Initial version
